/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */

package nodes

import (
	"context"
	"fmt"
	"net/http"

	"github.com/bpg/terraform-provider-proxmox/proxmox/api"
)

// GetConfig retrieves the config for a node.
func (c *Client) GetConfig(ctx context.Context) (*[]ConfigGetResponseData, error) {
	resBody := &ConfigGetResponseBody{}

	err := c.DoRequest(ctx, http.MethodGet, c.ExpandPath("config"), nil, resBody)
	if err != nil {
		return nil, fmt.Errorf("error retrieving node config: %w", err)
	}

	if resBody.Data == nil {
		return nil, api.ErrNoDataObjectInResponse
	}

	return resBody.Data, nil
}

// UpdateConfig updates the config for a node.
func (c *Client) UpdateConfig(ctx context.Context, d *ConfigUpdateRequestBody) error {
	err := c.DoRequest(ctx, http.MethodPost, c.ExpandPath("config"), d, nil)
	if err != nil {
		return fmt.Errorf("error updating node config: %w", err)
	}

	return nil
}
